utils

package
v0.0.0-...-8a749d3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 27, 2019 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckConnection

func CheckConnection() (bool, error)

Types

type RequestQuery

type RequestQuery struct {
	Term          string
	Order         string
	Asc           string
	Configuration string
	HoldSet       string
	Filter        string
	MinGrade      string
	MaxGrade      string
	Page          string
	PageSize      string
}

RequestQuery represents all the fields available in a query but as strings.

func (*RequestQuery) Query

func (q *RequestQuery) Query() (query.Query, error)

Query takes a RequestQuery and converts it properties to the correct types to make a Query object which can then be used to perform a search.

Jump to